dart_unitz library
A simple and expandable unit conversion library. Quickly and easily convert between units and apply math operations on any unit.
Classes
- Angle
- The base unit for Angle is the Radian.
- ArcMinute
- A minute of arc, arcminute, arc minute, or minute arc, denoted by the symbol ′, is a unit of angular measurement equal to 1/60 of one degree
- ArcSecond
- An arcsecond (denoted by the symbol “) is an angular measurement equal to 1/3600 of a degree or 1/60 of an arcminute.
- Atto
- The atto (symbol: a) is a decimal prefix. This denotes a factor of one quintillionth.
- BinaryPrefix
- An abstract class to provide a template for binary prefixes. These are sometimes referred to as "IEC prefixes".
- Bit
- The bit is the most basic unit of information in computing and digital communications.
- Byte
- The byte is a unit of digital information that most commonly consists of eight bits.
- Celsius
- The degree Celsius is the unit of temperature on the Celsius scale, one of two temperature scales used in the International System of Units (SI), the other being the Kelvin scale.
- Centi
- The centi (symbol: c) is a decimal prefix. This denotes a factor of one hundredth.
- Deca
- The deca (symbol: da) is a decimal prefix. This denotes a factor of ten.
- Deci
- The deci (symbol: d) is a decimal prefix. This denotes a factor of one tenth.
- DecimalPrefix
- An abstract class to provide a template for decimal prefixes. These are commonly called "Metric (SI) prefixes".
- Degree
- A degree (in full, a degree of arc, arc degree, or arcdegree), usually denoted by ° (the degree symbol), is a measurement of a plane angle in which one full rotation is 360 degrees
- Delisle
- The Delisle scale is a temperature scale, notable as one of the only temperature scales that is inverted from the amount of thermal energy it measures.
- Exa
- The exa (symbol: E) is a decimal prefix. This denotes a factor of one quintillion.
- Exbi
- The exbi (symbol: Ei) is a binary prefix.
- Fahrenheit
- Fahrenheit temperature scale, based on 32° for the freezing point of water and 212° for the boiling point of water, the interval between the two being divided into 180 equal parts.
- Femto
- The femto (symbol: f) is a decimal prefix. This denotes a factor of one quadrillionth.
- Foot
- The foot (pl. feet), standard symbol: ft, is a unit of length in the British imperial and United States customary systems of measurement.
- Gibi
- The gibi (symbol: Gi) is a binary prefix.
- Giga
- The giga (symbol: G) is a decimal prefix. This denotes a factor of one billion.
- Gradian
- The gradian, also known as the gon, grad, or grade, is a unit of measurement of an angle, defined as one hundredth of the right angle
- Hecto
- The hecto (symbol: h) is a decimal prefix. This denotes a factor of one hundred.
- Inch
- The inch (symbol: in or ″) is a unit of length in the British imperial and the United States customary systems of measurement. It is equal to 1/36 yard or 1/12 of a foot.
- Information
- The base unit for Information is the Bit.
- Kelvin
- The kelvin, symbol K, is the primary unit of temperature in the International System of Units (SI).
- Kibi
- The kibi (symbol: Ki) is a binary prefix.
- Kilo
- The kilo (symbol: k) is a decimal prefix. This denotes a factor of one thousand.
- Length
- The base unit for Length is the Metre.
- Mebi
- The mebi (symbol: Mi) is a binary prefix.
- Mega
- The mega (symbol: M) is a decimal prefix. This denotes a factor of one million.
- Meter
- An alias for Metre. For our American friends.
- Metre
- The metre, symbol m, is the primary unit of length in the International System of Units (SI)
- Micro
- The micro (symbol: μ) is a decimal prefix. This denotes a factor of one millionth.
- Milli
- The milli (symbol: m) is a decimal prefix. This denotes a factor of one thousandth.
- Nano
- The nano (symbol: n) is a decimal prefix. This denotes a factor of one billionth.
- NullPrefix
- A class used to represent a null/empty prefix.
- Pebi
- The pebi (symbol: Pi) is a binary prefix.
- Peta
- The peta (symbol: P) is a decimal prefix. This denotes a factor of one quadrillion.
- Pico
- The pico (symbol: p) is a decimal prefix. This denotes a factor of one trillionth.
- Quecto
- The quecto (symbol: q) is a decimal prefix. This denotes a factor of one nonillionth.
- Quetta
- The quetta (symbol: Q) is a decimal prefix. This denotes a factor of one nonillion.
- Radian
- The radian, denoted by the symbol rad, is the unit of angle in the International System of Units
- Rankine
- The Rankine scale is an absolute scale of thermodynamic temperature. Zero on the Rankine scale is absolute zero, but a temperature difference of one Rankine degree is defined as equal to one Fahrenheit degree, rather than the Celsius degree used on the Kelvin scale.
- Reaumur
- The Réaumur scale, also known as the "octogesimal division", is a temperature scale for which the melting and boiling points of water are defined as 0 and 80 degrees respectively.
- Romer
- The Rømer scale also known as Romer or Roemer, is a temperature scale, based on the freezing point of pure water being 7.5 degrees and the boiling point of water as 60 degrees.
- Ronna
- The ronna (symbol: R) is a decimal prefix. This denotes a factor of one octillion.
- Ronto
- The ronto (symbol: r) is a decimal prefix. This denotes a factor of one octillionth.
- Tebi
- The tebi (symbol: Ti) is a binary prefix.
- Temperature
- The base unit for Temperature is the Kelvin.
- Tera
- The tera (symbol: T) is a decimal prefix. This denotes a factor of one trillion.
- Unit
- An abstract class to provide a template for units.
- UnitPrefix
- An abstract class to provide a template for unit prefixes.
- Unitz
- The entry point for Unitz.
- Yobi
- The yobi (symbol: Yi) is a binary prefix.
- Yocto
- The yocto (symbol: y) is a decimal prefix. This denotes a factor of one septillionth.
- Yotta
- The yotta (symbol: Y) is a decimal prefix. This denotes a factor of one septillion.
- Zebi
- The zebi (symbol: Zi) is a binary prefix.
- Zepto
- The zepto (symbol: z) is a decimal prefix. This denotes a factor of one sextillionth.
- Zetta
- The zetta (symbol: Z) is a decimal prefix. This denotes a factor of one sextillion.
Extensions
- UnitExtension on Unit
- An extension to provide operators on Units.