Byte class

The byte is a unit of digital information that most commonly consists of eight bits.

https://en.wikipedia.org/wiki/Byte

Inheritance
Available extensions

Constructors

Byte([Object? value])
The byte is a unit of digital information that most commonly consists of eight bits.

Properties

base Unit
The base unit.
no setterinherited
formatted num
The formatted value.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name String
The name of this unit.
no setteroverride
pluralName String
The plural name for this unit.
no setteroverride
prefix UnitPrefix
The unit prefix for this value.
no setterinherited
prefixType Type
The type of prefix used for this unit.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol String
The symbol for this unit.
no setteroverride
value num
The precise value.
no setterinherited

Methods

compareTo(Unit other) int
Compares this object to another object.
inherited
fromBase(num base) num
Converts from the base unit to this unit.
override
newInstance([Object? value]) Unit
Creates a new instance of this class.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase() num
Converts this unit to the base unit.
override
toString() String
A string representation of this object.
inherited

Operators

operator %(Unit other) Unit

Available on Unit, provided by the UnitExtension extension

Modulo operator for two units.
operator *(Unit other) Unit

Available on Unit, provided by the UnitExtension extension

Multiplies two units together.
operator +(Unit other) Unit

Available on Unit, provided by the UnitExtension extension

Adds two units together.
operator -(Unit other) Unit

Available on Unit, provided by the UnitExtension extension

Subtracts two units.
operator /(Unit other) Unit

Available on Unit, provided by the UnitExtension extension

Divides two units.
operator <(Unit other) bool

Available on Unit, provided by the UnitExtension extension

Less than operator for two units.
operator <=(Unit other) bool

Available on Unit, provided by the UnitExtension extension

Less than or equal to operator for two units.
operator ==(Object other) bool
The equality operator.
inherited
operator >(Unit other) bool

Available on Unit, provided by the UnitExtension extension

Greater than operator for two units.
operator >=(Unit other) bool

Available on Unit, provided by the UnitExtension extension

Greater than or equal to operator for two units.
operator ~/(Unit other) Unit

Available on Unit, provided by the UnitExtension extension

Integer divides two units.