Kibi class
The kibi (symbol: Ki) is a binary prefix.
- Inheritance
-
- Object
- BinaryPrefix
- Kibi
Constructors
- Kibi()
- The kibi (symbol: Ki) is a binary prefix.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The name of this prefix.
no setteroverride
- pluralWord → String
-
The plural word for this prefix.
no setteroverride
- power → num
-
The power of this prefix.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- symbol → String
-
The symbol for this prefix.
no setteroverride
- word → String
-
The friendly word (aka numeral/number word) for this prefix.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited